@@ -4,14 +4,23 @@ import logging
 
 _logger = logging.getLogger(__name__)
 
+
 class ScpiResource(NamedTuple):
+    """A SCPI resource object"""
     transport: Type[ScpiTransports]
+    """Transport of the SCPI resource"""
     address: Any
+    """address (e.g. TCP/IP hostname/port) of resource"""
     location: Optional[str] = None
+    """Location (e.g. USB bus hierarchy) of resource"""
     name: Optional[str] = None
+    """Descriptive name of resource"""
     manufacturer: Optional[str] = None
+    """Descriptive manufacturer string of resource"""
     model: Optional[str] = None
+    """Model description of resource"""
     serialnum: Optional[str] = None
+    """Serial number of resource"""
     info: Optional[Any] = None
 
     @classmethod
@@ -19,8 +28,8 @@ class ScpiResource(NamedTuple):
         """Find SCPI devices connected to system.
 
         By default lists all available possible SCPI devices. However behaviour can be controlled using
-        kwargs supported by the transport classes."""
-
+        kwargs supported by the transport classes.
+        """
         if transports is None: transports = ScpiTransportBase.__subclasses__()
 
         resources = []
